# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: api.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'api.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\tapi.proto\x12\nsepia2.rpc\x1a\x1bgoogle/protobuf/empty.proto\"u\n\x0fPrimaGatingInfo\x12\x13\n\x0bmin_on_time\x18\x01 \x01(\x05\x12\x13\n\x0bmax_on_time\x18\x02 \x01(\x05\x12\x1b\n\x13min_off_time_factor\x18\x03 \x01(\x05\x12\x1b\n\x13max_off_time_factor\x18\x04 \x01(\x05\"Q\n\x10TriggerLevelInfo\x12\x13\n\x0btrg_min_lvl\x18\x01 \x01(\x05\x12\x13\n\x0btrg_max_lvl\x18\x02 \x01(\x05\x12\x13\n\x0btrg_lvl_res\x18\x03 \x01(\x05\"j\n\x0bTriggerInfo\x12\x13\n\x0btrg_src_idx\x18\x01 \x01(\x05\x12\x0f\n\x07trg_src\x18\x02 \x01(\t\x12\x19\n\x11\x66requency_enabled\x18\x03 \x01(\x08\x12\x1a\n\x12trig_level_enabled\x18\x04 \x01(\x08\"9\n\rPrimaModeInfo\x12\x15\n\roper_mode_idx\x18\x01 \x01(\x05\x12\x11\n\toper_mode\x18\x02 \x01(\t\"\\\n\x0cPrimaDevInfo\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65vice_type\x18\x02 \x01(\t\x12\x12\n\nfw_version\x18\x03 \x01(\t\x12\x10\n\x08wl_count\x18\x04 \x01(\x05\"Z\n\x11\x46wrRequestSupport\x12\x10\n\x08preamble\x18\x01 \x01(\t\x12\x12\n\ncalling_sw\x18\x02 \x01(\t\x12\x0f\n\x07options\x18\x03 \x01(\x05\x12\x0e\n\x06\x62uffer\x18\x04 \x01(\x05\"O\n\nUptimeInfo\x12\x13\n\x0bmain_pwr_up\x18\x01 \x01(\r\x12\x15\n\ractive_pwr_up\x18\x02 \x01(\r\x12\x15\n\rscaled_pwr_up\x18\x03 \x01(\r\"Y\n\nModuleInfo\x12\x0f\n\x07slot_id\x18\x01 \x01(\x05\x12\x12\n\nis_primary\x18\x02 \x01(\x08\x12\x15\n\ris_back_plane\x18\x03 \x01(\x08\x12\x0f\n\x07has_UTC\x18\x04 \x01(\x08\"^\n\x08\x46wrError\x12\x10\n\x08\x65rr_code\x18\x01 \x01(\x05\x12\r\n\x05phase\x18\x02 \x01(\x05\x12\x10\n\x08location\x18\x03 \x01(\x05\x12\x0c\n\x04slot\x18\x04 \x01(\x05\x12\x11\n\tcondition\x18\x05 \x01(\t\"7\n\tUsbDevice\x12\x14\n\x0cProductModel\x18\x01 \x01(\t\x12\x14\n\x0cSerialNumber\x18\x02 \x01(\t\"\x07\n\x05\x45mpty\"\x17\n\x06String\x12\r\n\x05value\x18\x01 \x01(\t\"\x15\n\x04\x42ool\x12\r\n\x05value\x18\x01 \x01(\x08\"\x16\n\x05Int32\x12\r\n\x05value\x18\x01 \x01(\x05\"\x17\n\x06Uint32\x12\r\n\x05value\x18\x01 \x01(\r\"\x1c\n\tDeviceIdx\x12\x0f\n\x07\x64\x65v_idx\x18\x01 \x01(\x05\")\n\x16LibDecodeErrorResponse\x12\x0f\n\x07\x65rr_str\x18\x01 \x01(\t\"\x1a\n\x07Version\x12\x0f\n\x07version\x18\x01 \x01(\t\"=\n\x17GetStrDescrByIdxRequest\x12\x0f\n\x07\x64\x65v_idx\x18\x01 \x01(\x05\x12\x11\n\tdescr_idx\x18\x02 \x01(\x05\"$\n\x0f\x45rrPhaseRequest\x12\x11\n\terr_phase\x18\x01 \x01(\x05\"9\n\x18\x46wrSetWorkingModeRequest\x12\x0f\n\x07\x64\x65v_idx\x18\x01 \x01(\x05\x12\x0c\n\x04mode\x18\x02 \x01(\x05\"?\n\x13GetModuleMapRequest\x12\x0f\n\x07\x64\x65v_idx\x18\x01 \x01(\x05\x12\x17\n\x0fperform_restart\x18\x02 \x01(\x08\"=\n\x17\x46requencyLimitsResponse\x12\x10\n\x08min_freq\x18\x01 \x01(\x05\x12\x10\n\x08max_freq\x18\x02 \x01(\x05\"1\n\rMapIdxRequest\x12\x0f\n\x07\x64\x65v_idx\x18\x01 \x01(\x05\x12\x0f\n\x07map_idx\x18\x02 \x01(\x05\".\n\nPriRequest\x12\x0f\n\x07\x64\x65v_idx\x18\x01 \x01(\x05\x12\x0f\n\x07slot_id\x18\x02 \x01(\x05\"Q\n\x13SetFrequencyRequest\x12\'\n\x07pri_req\x18\x01 \x01(\x0b\x32\x16.sepia2.rpc.PriRequest\x12\x11\n\tfrequency\x18\x02 \x01(\x05\"W\n\x14GatingEnabledRequest\x12\'\n\x07pri_req\x18\x01 \x01(\x0b\x32\x16.sepia2.rpc.PriRequest\x12\x16\n\x0egating_enabled\x18\x02 \x01(\x08\"L\n\x11WavelengthRequest\x12\'\n\x07pri_req\x18\x01 \x01(\x0b\x32\x16.sepia2.rpc.PriRequest\x12\x0e\n\x06wl_idx\x18\x02 \x01(\x05\"W\n\x13SetIntensityRequest\x12-\n\x06wl_req\x18\x01 \x01(\x0b\x32\x1d.sepia2.rpc.WavelengthRequest\x12\x11\n\tintensity\x18\x02 \x01(\x05\"r\n\x14OperationModeRequest\x12\'\n\x07pri_req\x18\x01 \x01(\x0b\x32\x16.sepia2.rpc.PriRequest\x12\x31\n\x0eoper_mode_enum\x18\x02 \x01(\x0e\x32\x19.sepia2.rpc.OperationMode\"A\n\x15OperationModeResponse\x12(\n\x05value\x18\x01 \x01(\x0e\x32\x19.sepia2.rpc.OperationMode\"T\n\x14TriggerSourceRequest\x12\'\n\x07pri_req\x18\x01 \x01(\x0b\x32\x16.sepia2.rpc.PriRequest\x12\x13\n\x0btrg_src_idx\x18\x02 \x01(\x05\"O\n\x13TriggerLevelRequest\x12\'\n\x07pri_req\x18\x01 \x01(\x0b\x32\x16.sepia2.rpc.PriRequest\x12\x0f\n\x07trg_lvl\x18\x02 \x01(\x05\"6\n\nGatingData\x12\x0f\n\x07on_time\x18\x01 \x01(\x05\x12\x17\n\x0foff_time_factor\x18\x02 \x01(\x05\"i\n\x11GatingDataRequest\x12\'\n\x07pri_req\x18\x01 \x01(\x0b\x32\x16.sepia2.rpc.PriRequest\x12+\n\x0bgating_data\x18\x02 \x01(\x0b\x32\x16.sepia2.rpc.GatingData\"W\n\x14HighImpedanceRequest\x12\'\n\x07pri_req\x18\x01 \x01(\x0b\x32\x16.sepia2.rpc.PriRequest\x12\x16\n\x0ehigh_impedance\x18\x02 \x01(\x08\"[\n\x18\x46wrRequestSupportRequest\x12\x0f\n\x07\x64\x65v_idx\x18\x01 \x01(\x05\x12.\n\x07\x66wr_req\x18\x02 \x01(\x0b\x32\x1d.sepia2.rpc.FwrRequestSupport\"\xda\x9d\x01\n\x05\x45rror\x12\x31\n\x05\x65rror\x18\x01 \x01(\x0e\x32\x1d.sepia2.rpc.Error.Sepia2ErrorH\x00\x88\x01\x01\"\x92\x9d\x01\n\x0bSepia2Error\x12\x17\n\x13SEPIA2_ERR_NO_ERROR\x10\x00\x12\x32\n%SEPIA2_ERR_FW_MEMORY_ALLOCATION_ERROR\x10\x97\xf8\xff\xff\xff\xff\xff\xff\xff\x01\x12\x42\n5SEPIA2_ERR_FW_CRC_ERROR_WHILE_CHECKING_SCM_828_MODULE\x10\x96\xf8\xff\xff\xff\xff\xff\xff\xff\x01\x12=\n0SEPIA2_ERR_FW_CRC_ERROR_WHILE_CHECKING_BACKPLANE\x10\x95\xf8\xff\xff\xff\xff\xff\xff\xff\x01\x12:\n-SEPIA2_ERR_FW_CRC_ERROR_WHILE_CHECKING_MODULE\x10\x94\xf8\xff\xff\xff\xff\xff\xff\xff\x01\x12(\n\x1bSEPIA2_ERR_FW_MAPSIZE_ERROR\x10\x93\xf8\xff\xff\xff\xff\xff\xff\xff\x01\x12.\n!SEPIA2_ERR_FW_UNKNOWN_ERROR_PHASE\x10\x92\xf8\xff\xff\xff\xff\xff\xff\xff\x01\x12\x32\n%SEPIA2_ERR_FW_INSUFFICIENT_FW_VERSION\x10\x91\xf8\xff\xff\xff\xff\xff\xff\xff\x01\x12,\n\x1fSEPIA2_ERR_FW_WRONG_WORKINGMODE\x10\x90\xf8\xff\xff\xff\xff\xff\xff\xff\x01\x12\x30\n#SEPIA2_ERR_FW_ILLEGAL_MODULE_CHANGE\x10\xa9\xf7\xff\xff\xff\xff\xff\xff\xff\x01\x12\x30\n#SEPIA2_ERR_USB_WRONG_DRIVER_VERSION\x10\xaf\xf0\xff\xff\xff\xff\xff\xff\xff\x01\x12-\n SEPIA2_ERR_USB_OPEN_DEVICE_ERROR\x10\xae\xf0\xff\xff\xff\xff\xff\xff\xff\x01\x12\'\n\x1aSEPIA2_ERR_USB_DEVICE_BUSY\x10\xad\xf0\xff\xff\xff\xff\xff\xff\xff\x01\x12.\n!SEPIA2_ERR_USB_CLOSE_DEVICE_ERROR\x10\xab\xf0\xff\xff\xff\xff\xff\xff\xff\x01\x12*\n\x1dSEPIA2_ERR_USB_DEVICE_CHANGED\x10\xaa\xf0\xff\xff\xff\xff\xff\xff\xff\x01\x12)\n\x1cSEPIA2_ERR_I2C_ADDRESS_ERROR\x10\xa6\xf0\xff\xff\xff\xff\xff\xff\xff\x01\x12.\n!SEPIA2_ERR_USB_DEVICE_INDEX_ERROR\x10\xa5\xf0\xff\xff\xff\xff\xff\xff\xff\x01\x12\x34\n\'SEPIA2_ERR_I2C_ILLEGAL_MULTIPLEXER_PATH\x10\xa4\xf0\xff\xff\xff\xff\xff\xff\xff\x01\x12\x35\n(SEPIA2_ERR_I2C_ILLEGAL_MULTIPLEXER_LEVEL\x10\xa3\xf0\xff\xff\xff\xff\xff\xff\xff\x01\x12+\n\x1eSEPIA2_ERR_I2C_ILLEGAL_SLOT_ID\x10\xa2\xf0\xff\xff\xff\xff\xff\xff\xff\x01\x12.\n!SEPIA2_ERR_FRAM_NO_UPTIME_COUNTER\x10\xa1\xf0\xff\xff\xff\xff\xff\xff\xff\x01\x12-\n SEPIA2_ERR_FRAM_BLOCKWRITE_ERROR\x10\x9c\xf0\xff\xff\xff\xff\xff\xff\xff\x01\x12,\n\x1fSEPIA2_ERR_FRAM_BLOCKREAD_ERROR\x10\x9b\xf0\xff\xff\xff\xff\xff\xff\xff\x01\x12\x31\n$SEPIA2_ERR_FRAM_CRC_BLOCKCHECK_ERROR\x10\x9a\xf0\xff\xff\xff\xff\xff\xff\xff\x01\x12\x32\n%SEPIA2_ERR_RAM_BLOCK_ALLOCATION_ERROR\x10\x99\xf0\xff\xff\xff\xff\xff\xff\xff\x01\x12\x38\n+SEPIA2_ERR_RAM_SECURE_MEMORY_HANDLING_ERROR\x10\x98\xf0\xff\xff\xff\xff\xff\xff\xff\x01\x12@\n3SEPIA2_ERR_I2C_INITIALISING_COMMAND_EXECUTION_ERROR\x10\xcc\xef\xff\xff\xff\xff\xff\xff\xff\x01\x12@\n3SEPIA2_ERR_I2C_FETCHING_INITIALISING_COMMANDS_ERROR\x10\xcb\xef\xff\xff\xff\xff\xff\xff\xff\x01\x12?\n2SEPIA2_ERR_I2C_WRITING_INITIALISING_COMMANDS_ERROR\x10\xca\xef\xff\xff\xff\xff\xff\xff\xff\x01\x12\x34\n\'SEPIA2_ERR_I2C_MODULE_CALIBRATING_ERROR\x10\xe8\xee\xff\xff\xff\xff\xff\xff\xff\x01\x12?\n2SEPIA2_ERR_I2C_FETCHING_CALIBRATING_COMMANDS_ERROR\x10\xe7\xee\xff\xff\xff\xff\xff\xff\xff\x01\x12>\n1SEPIA2_ERR_I2C_WRITING_CALIBRATING_COMMANDS_ERROR\x10\xe6\xee\xff\xff\xff\xff\xff\xff\xff\x01\x12+\n\x1eSEPIA2_ERR_DCL_FILE_OPEN_ERROR\x10\x83\xee\xff\xff\xff\xff\xff\xff\xff\x01\x12-\n SEPIA2_ERR_DCL_WRONG_FILE_LENGTH\x10\x82\xee\xff\xff\xff\xff\xff\xff\xff\x01\x12+\n\x1eSEPIA2_ERR_DCL_FILE_READ_ERROR\x10\x81\xee\xff\xff\xff\xff\xff\xff\xff\x01\x12/\n\"SEPIA2_ERR_FRAM_IS_WRITE_PROTECTED\x10\x80\xee\xff\xff\xff\xff\xff\xff\xff\x01\x12?\n2SEPIA2_ERR_DCL_FILE_SPECIFIES_DIFFERENT_MODULETYPE\x10\xff\xed\xff\xff\xff\xff\xff\xff\xff\x01\x12\x42\n5SEPIA2_ERR_DCL_FILE_SPECIFIES_DIFFERENT_SERIAL_NUMBER\x10\xfe\xed\xff\xff\xff\xff\xff\xff\xff\x01\x12,\n\x1fSEPIA2_ERR_I2C_INVALID_ARGUMENT\x10\xc7\xe8\xff\xff\xff\xff\xff\xff\xff\x01\x12>\n1SEPIA2_ERR_I2C_NO_ACKNOWLEDGE_ON_WRITE_ADRESSBYTE\x10\xc6\xe8\xff\xff\xff\xff\xff\xff\xff\x01\x12=\n0SEPIA2_ERR_I2C_NO_ACKNOWLEDGE_ON_READ_ADRESSBYTE\x10\xc5\xe8\xff\xff\xff\xff\xff\xff\xff\x01\x12<\n/SEPIA2_ERR_I2C_NO_ACKNOWLEDGE_ON_WRITE_DATABYTE\x10\xc4\xe8\xff\xff\xff\xff\xff\xff\xff\x01\x12+\n\x1eSEPIA2_ERR_I2C_READ_BACK_ERROR\x10\xc3\xe8\xff\xff\xff\xff\xff\xff\xff\x01\x12&\n\x19SEPIA2_ERR_I2C_READ_ERROR\x10\xc2\xe8\xff\xff\xff\xff\xff\xff\xff\x01\x12\'\n\x1aSEPIA2_ERR_I2C_WRITE_ERROR\x10\xc1\xe8\xff\xff\xff\xff\xff\xff\xff\x01\x12&\n\x19SEPIA2_ERR_I_O_FILE_ERROR\x10\xbf\xe8\xff\xff\xff\xff\xff\xff\xff\x01\x12-\n SEPIA2_ERR_I2C_MULTIPLEXER_ERROR\x10\xba\xe8\xff\xff\xff\xff\xff\xff\xff\x01\x12\x32\n%SEPIA2_ERR_I2C_MULTIPLEXER_PATH_ERROR\x10\xb9\xe8\xff\xff\xff\xff\xff\xff\xff\x01\x12\'\n\x1aSEPIA2_ERR_USB_INIT_FAILED\x10\x80\xe7\xff\xff\xff\xff\xff\xff\xff\x01\x12,\n\x1fSEPIA2_ERR_USB_INVALID_ARGUMENT\x10\xff\xe6\xff\xff\xff\xff\xff\xff\xff\x01\x12-\n SEPIA2_ERR_USB_DEVICE_STILL_OPEN\x10\xfe\xe6\xff\xff\xff\xff\xff\xff\xff\x01\x12%\n\x18SEPIA2_ERR_USB_NO_MEMORY\x10\xfd\xe6\xff\xff\xff\xff\xff\xff\xff\x01\x12\'\n\x1aSEPIA2_ERR_USB_OPEN_FAILED\x10\xfc\xe6\xff\xff\xff\xff\xff\xff\xff\x01\x12\x31\n$SEPIA2_ERR_USB_GET_DESCRIPTOR_FAILED\x10\xfb\xe6\xff\xff\xff\xff\xff\xff\xff\x01\x12\x30\n#SEPIA2_ERR_USB_INAPPROPRIATE_DEVICE\x10\xfa\xe6\xff\xff\xff\xff\xff\xff\xff\x01\x12\'\n\x1aSEPIA2_ERR_USB_BUSY_DEVICE\x10\xf9\xe6\xff\xff\xff\xff\xff\xff\xff\x01\x12*\n\x1dSEPIA2_ERR_USB_INVALID_HANDLE\x10\xf8\xe6\xff\xff\xff\xff\xff\xff\xff\x01\x12\x35\n(SEPIA2_ERR_USB_INVALID_DESCRIPTOR_BUFFER\x10\xf7\xe6\xff\xff\xff\xff\xff\xff\xff\x01\x12)\n\x1cSEPIA2_ERR_USB_IOCTRL_FAILED\x10\xf6\xe6\xff\xff\xff\xff\xff\xff\xff\x01\x12\'\n\x1aSEPIA2_ERR_USB_VCMD_FAILED\x10\xf5\xe6\xff\xff\xff\xff\xff\xff\xff\x01\x12(\n\x1bSEPIA2_ERR_USB_NO_SUCH_PIPE\x10\xf4\xe6\xff\xff\xff\xff\xff\xff\xff\x01\x12\x38\n+SEPIA2_ERR_USB_REGISTER_NOTIFICATION_FAILED\x10\xf3\xe6\xff\xff\xff\xff\xff\xff\xff\x01\x12*\n\x1dSEPIA2_ERR_USB_UNKNOWN_DEVICE\x10\xf2\xe6\xff\xff\xff\xff\xff\xff\xff\x01\x12(\n\x1bSEPIA2_ERR_USB_WRONG_DRIVER\x10\xf1\xe6\xff\xff\xff\xff\xff\xff\xff\x01\x12)\n\x1cSEPIA2_ERR_USB_WINDOWS_ERROR\x10\xf0\xe6\xff\xff\xff\xff\xff\xff\xff\x01\x12+\n\x1eSEPIA2_ERR_USB_DEVICE_NOT_OPEN\x10\xef\xe6\xff\xff\xff\xff\xff\xff\xff\x01\x12(\n\x1bSEPIA2_ERR_I2C_DEVICE_ERROR\x10\xc8\xe6\xff\xff\xff\xff\xff\xff\xff\x01\x12\x31\n$SEPIA2_ERR_LMP1_ADC_TABLES_NOT_FOUND\x10\xd3\xe4\xff\xff\xff\xff\xff\xff\xff\x01\x12)\n\x1cSEPIA2_ERR_LMP1_ADC_OVERFLOW\x10\xd2\xe4\xff\xff\xff\xff\xff\xff\xff\x01\x12*\n\x1dSEPIA2_ERR_LMP1_ADC_UNDERFLOW\x10\xd1\xe4\xff\xff\xff\xff\xff\xff\xff\x01\x12:\n-SEPIA2_ERR_SCM_VOLTAGE_LIMITS_TABLE_NOT_FOUND\x10\xdf\xe0\xff\xff\xff\xff\xff\xff\xff\x01\x12:\n-SEPIA2_ERR_SCM_VOLTAGE_SCALING_LIST_NOT_FOUND\x10\xde\xe0\xff\xff\xff\xff\xff\xff\xff\x01\x12?\n2SEPIA2_ERR_SCM_REPEATEDLY_MEASURED_VOLTAGE_FAILURE\x10\xdd\xe0\xff\xff\xff\xff\xff\xff\xff\x01\x12?\n2SEPIA2_ERR_SCM_POWER_SUPPLY_LINE_0_VOLTAGE_TOO_LOW\x10\xd6\xe0\xff\xff\xff\xff\xff\xff\xff\x01\x12?\n2SEPIA2_ERR_SCM_POWER_SUPPLY_LINE_1_VOLTAGE_TOO_LOW\x10\xd5\xe0\xff\xff\xff\xff\xff\xff\xff\x01\x12?\n2SEPIA2_ERR_SCM_POWER_SUPPLY_LINE_2_VOLTAGE_TOO_LOW\x10\xd4\xe0\xff\xff\xff\xff\xff\xff\xff\x01\x12?\n2SEPIA2_ERR_SCM_POWER_SUPPLY_LINE_3_VOLTAGE_TOO_LOW\x10\xd3\xe0\xff\xff\xff\xff\xff\xff\xff\x01\x12?\n2SEPIA2_ERR_SCM_POWER_SUPPLY_LINE_4_VOLTAGE_TOO_LOW\x10\xd2\xe0\xff\xff\xff\xff\xff\xff\xff\x01\x12?\n2SEPIA2_ERR_SCM_POWER_SUPPLY_LINE_5_VOLTAGE_TOO_LOW\x10\xd1\xe0\xff\xff\xff\xff\xff\xff\xff\x01\x12?\n2SEPIA2_ERR_SCM_POWER_SUPPLY_LINE_6_VOLTAGE_TOO_LOW\x10\xd0\xe0\xff\xff\xff\xff\xff\xff\xff\x01\x12?\n2SEPIA2_ERR_SCM_POWER_SUPPLY_LINE_7_VOLTAGE_TOO_LOW\x10\xcf\xe0\xff\xff\xff\xff\xff\xff\xff\x01\x12@\n3SEPIA2_ERR_SCM_POWER_SUPPLY_LINE_0_VOLTAGE_TOO_HIGH\x10\xcc\xe0\xff\xff\xff\xff\xff\xff\xff\x01\x12@\n3SEPIA2_ERR_SCM_POWER_SUPPLY_LINE_1_VOLTAGE_TOO_HIGH\x10\xcb\xe0\xff\xff\xff\xff\xff\xff\xff\x01\x12@\n3SEPIA2_ERR_SCM_POWER_SUPPLY_LINE_2_VOLTAGE_TOO_HIGH\x10\xca\xe0\xff\xff\xff\xff\xff\xff\xff\x01\x12@\n3SEPIA2_ERR_SCM_POWER_SUPPLY_LINE_3_VOLTAGE_TOO_HIGH\x10\xc9\xe0\xff\xff\xff\xff\xff\xff\xff\x01\x12@\n3SEPIA2_ERR_SCM_POWER_SUPPLY_LINE_4_VOLTAGE_TOO_HIGH\x10\xc8\xe0\xff\xff\xff\xff\xff\xff\xff\x01\x12@\n3SEPIA2_ERR_SCM_POWER_SUPPLY_LINE_5_VOLTAGE_TOO_HIGH\x10\xc7\xe0\xff\xff\xff\xff\xff\xff\xff\x01\x12@\n3SEPIA2_ERR_SCM_POWER_SUPPLY_LINE_6_VOLTAGE_TOO_HIGH\x10\xc6\xe0\xff\xff\xff\xff\xff\xff\xff\x01\x12@\n3SEPIA2_ERR_SCM_POWER_SUPPLY_LINE_7_VOLTAGE_TOO_HIGH\x10\xc5\xe0\xff\xff\xff\xff\xff\xff\xff\x01\x12K\n>SEPIA2_ERR_SCM_POWER_SUPPLY_LASER_TURNING_OFF_VOLTAGE_TOO_HIGH\x10\xc2\xe0\xff\xff\xff\xff\xff\xff\xff\x01\x12;\n.SEPIA2_ERR_SCM_INVALID_TEMPERATURE_TABLE_COUNT\x10\xb8\xe0\xff\xff\xff\xff\xff\xff\xff\x01\x12\x34\n\'SEPIA2_ERR_SCM_TCONFG_TABLE_READ_FAILED\x10\xb7\xe0\xff\xff\xff\xff\xff\xff\xff\x01\x12;\n.SEPIA2_ERR_SCM_INVALID_NUMBER_OF_TABLE_ENTRIES\x10\xb6\xe0\xff\xff\xff\xff\xff\xff\xff\x01\x12\x33\n&SEPIA2_ERR_SCM_INVALID_TIMERTICK_VALUE\x10\xb5\xe0\xff\xff\xff\xff\xff\xff\xff\x01\x12;\n.SEPIA2_ERR_SCM_INVALID_TEMPERATURE_VALUE_TABLE\x10\xb4\xe0\xff\xff\xff\xff\xff\xff\xff\x01\x12\x37\n*SEPIA2_ERR_SCM_INVALID_DAC_CONTROL_TABLE_A\x10\xb3\xe0\xff\xff\xff\xff\xff\xff\xff\x01\x12\x37\n*SEPIA2_ERR_SCM_INVALID_DAC_CONTROL_TABLE_B\x10\xb2\xe0\xff\xff\xff\xff\xff\xff\xff\x01\x12\x39\n,SEPIA2_ERR_SCM_TEMPERATURE_TABLE_READ_FAILED\x10\xb1\xe0\xff\xff\xff\xff\xff\xff\xff\x01\x12@\n3SEPIA2_ERR_SOM_INT_OSCILLATOR_S_FREQ_LIST_NOT_FOUND\x10\xf7\xd8\xff\xff\xff\xff\xff\xff\xff\x01\x12\x37\n*SEPIA2_ERR_SOM_TRIGGER_MODE_LIST_NOT_FOUND\x10\xf6\xd8\xff\xff\xff\xff\xff\xff\xff\x01\x12\x33\n&SEPIA2_ERR_SOM_TRIGGER_LEVEL_NOT_FOUND\x10\xf5\xd8\xff\xff\xff\xff\xff\xff\xff\x01\x12J\n=SEPIA2_ERR_SOM_PREDIVIDER_PRETRIGGER_OR_TRIGGERMASK_NOT_FOUND\x10\xf4\xd8\xff\xff\xff\xff\xff\xff\xff\x01\x12\x31\n$SEPIA2_ERR_SOM_BURSTLENGTH_NOT_FOUND\x10\xf3\xd8\xff\xff\xff\xff\xff\xff\xff\x01\x12<\n/SEPIA2_ERR_SOM_OUTPUT_AND_SYNC_ENABLE_NOT_FOUND\x10\xf2\xd8\xff\xff\xff\xff\xff\xff\xff\x01\x12\x37\n*SEPIA2_ERR_SOM_TRIGGER_LEVEL_OUT_OF_BOUNDS\x10\xf1\xd8\xff\xff\xff\xff\xff\xff\xff\x01\x12\x39\n,SEPIA2_ERR_SOM_ILLEGAL_FREQUENCY_TRIGGERMODE\x10\xf0\xd8\xff\xff\xff\xff\xff\xff\xff\x01\x12\x35\n(SEPIA2_ERR_SOM_ILLEGAL_FREQUENCY_DIVIDER\x10\xef\xd8\xff\xff\xff\xff\xff\xff\xff\x01\x12+\n\x1eSEPIA2_ERR_SOM_ILLEGAL_PRESYNC\x10\xee\xd8\xff\xff\xff\xff\xff\xff\xff\x01\x12\x30\n#SEPIA2_ERR_SOM_ILLEGAL_BURST_LENGTH\x10\xed\xd8\xff\xff\xff\xff\xff\xff\xff\x01\x12\x31\n$SEPIA2_ERR_SOM_AUX_IO_CTRL_NOT_FOUND\x10\xec\xd8\xff\xff\xff\xff\xff\xff\xff\x01\x12\x30\n#SEPIA2_ERR_SOM_ILLEGAL_AUX_OUT_CTRL\x10\xeb\xd8\xff\xff\xff\xff\xff\xff\xff\x01\x12/\n\"SEPIA2_ERR_SOM_ILLEGAL_AUX_IN_CTRL\x10\xea\xd8\xff\xff\xff\xff\xff\xff\xff\x01\x12\x41\n4SEPIA2_ERR_SOMD_INT_OSCILLATOR_S_FREQ_LIST_NOT_FOUND\x10\xc5\xd8\xff\xff\xff\xff\xff\xff\xff\x01\x12\x38\n+SEPIA2_ERR_SOMD_TRIGGER_MODE_LIST_NOT_FOUND\x10\xc4\xd8\xff\xff\xff\xff\xff\xff\xff\x01\x12\x34\n\'SEPIA2_ERR_SOMD_TRIGGER_LEVEL_NOT_FOUND\x10\xc3\xd8\xff\xff\xff\xff\xff\xff\xff\x01\x12K\n>SEPIA2_ERR_SOMD_PREDIVIDER_PRETRIGGER_OR_TRIGGERMASK_NOT_FOUND\x10\xc2\xd8\xff\xff\xff\xff\xff\xff\xff\x01\x12\x32\n%SEPIA2_ERR_SOMD_BURSTLENGTH_NOT_FOUND\x10\xc1\xd8\xff\xff\xff\xff\xff\xff\xff\x01\x12=\n0SEPIA2_ERR_SOMD_OUTPUT_AND_SYNC_ENABLE_NOT_FOUND\x10\xc0\xd8\xff\xff\xff\xff\xff\xff\xff\x01\x12\x38\n+SEPIA2_ERR_SOMD_TRIGGER_LEVEL_OUT_OF_BOUNDS\x10\xbf\xd8\xff\xff\xff\xff\xff\xff\xff\x01\x12:\n-SEPIA2_ERR_SOMD_ILLEGAL_FREQUENCY_TRIGGERMODE\x10\xbe\xd8\xff\xff\xff\xff\xff\xff\xff\x01\x12\x36\n)SEPIA2_ERR_SOMD_ILLEGAL_FREQUENCY_DIVIDER\x10\xbd\xd8\xff\xff\xff\xff\xff\xff\xff\x01\x12,\n\x1fSEPIA2_ERR_SOMD_ILLEGAL_PRESYNC\x10\xbc\xd8\xff\xff\xff\xff\xff\xff\xff\x01\x12\x31\n$SEPIA2_ERR_SOMD_ILLEGAL_BURST_LENGTH\x10\xbb\xd8\xff\xff\xff\xff\xff\xff\xff\x01\x12\x32\n%SEPIA2_ERR_SOMD_AUX_IO_CTRL_NOT_FOUND\x10\xba\xd8\xff\xff\xff\xff\xff\xff\xff\x01\x12\x31\n$SEPIA2_ERR_SOMD_ILLEGAL_AUX_OUT_CTRL\x10\xb9\xd8\xff\xff\xff\xff\xff\xff\xff\x01\x12\x30\n#SEPIA2_ERR_SOMD_ILLEGAL_AUX_IN_CTRL\x10\xb8\xd8\xff\xff\xff\xff\xff\xff\xff\x01\x12\x31\n$SEPIA2_ERR_SOMD_ILLEGAL_OUT_MUX_CTRL\x10\xb1\xd8\xff\xff\xff\xff\xff\xff\xff\x01\x12\x38\n+SEPIA2_ERR_SOMD_OUTPUT_DELAY_DATA_NOT_FOUND\x10\xb0\xd8\xff\xff\xff\xff\xff\xff\xff\x01\x12\x36\n)SEPIA2_ERR_SOMD_ILLEGAL_OUTPUT_DELAY_DATA\x10\xaf\xd8\xff\xff\xff\xff\xff\xff\xff\x01\x12>\n1SEPIA2_ERR_SOMD_DELAY_NOT_ALLOWED_IN_TRIGGER_MODE\x10\xae\xd8\xff\xff\xff\xff\xff\xff\xff\x01\x12\x30\n#SEPIA2_ERR_SOMD_DEVICE_INITIALIZING\x10\xad\xd8\xff\xff\xff\xff\xff\xff\xff\x01\x12(\n\x1bSEPIA2_ERR_SOMD_DEVICE_BUSY\x10\xac\xd8\xff\xff\xff\xff\xff\xff\xff\x01\x12+\n\x1eSEPIA2_ERR_SOMD_PLL_NOT_LOCKED\x10\xab\xd8\xff\xff\xff\xff\xff\xff\xff\x01\x12-\n SEPIA2_ERR_SOMD_FW_UPDATE_FAILED\x10\xa8\xd8\xff\xff\xff\xff\xff\xff\xff\x01\x12\x30\n#SEPIA2_ERR_SOMD_FW_CRC_CHECK_FAILED\x10\xa7\xd8\xff\xff\xff\xff\xff\xff\xff\x01\x12\x33\n&SEPIA2_ERR_SOMD_HW_TRIGGERSOURCE_ERROR\x10\x93\xd8\xff\xff\xff\xff\xff\xff\xff\x01\x12\x34\n\'SEPIA2_ERR_SOMD_HW_SYCHRONIZE_NOW_ERROR\x10\x92\xd8\xff\xff\xff\xff\xff\xff\xff\x01\x12\x30\n#SEPIA2_ERR_SOMD_HW_SYNC_RANGE_ERROR\x10\x91\xd8\xff\xff\xff\xff\xff\xff\xff\x01\x12\x34\n\'SEPIA2_ERR_SOMD_HW_ILLEGAL_OUT_MUX_CTRL\x10\x90\xd8\xff\xff\xff\xff\xff\xff\xff\x01\x12/\n\"SEPIA2_ERR_SOMD_HW_SET_DELAY_ERROR\x10\x8f\xd8\xff\xff\xff\xff\xff\xff\xff\x01\x12\x34\n\'SEPIA2_ERR_SOMD_HW_AUX_IO_COMMAND_ERROR\x10\x8e\xd8\xff\xff\xff\xff\xff\xff\xff\x01\x12.\n!SEPIA2_ERR_SOMD_HW_PLL_NOT_STABLE\x10\x8d\xd8\xff\xff\xff\xff\xff\xff\xff\x01\x12\x32\n%SEPIA2_ERR_SOMD_HW_BURST_LENGTH_ERROR\x10\x8c\xd8\xff\xff\xff\xff\xff\xff\xff\x01\x12\x35\n(SEPIA2_ERR_SOMD_HW_OUT_MUX_COMMAND_ERROR\x10\x8b\xd8\xff\xff\xff\xff\xff\xff\xff\x01\x12\x36\n)SEPIA2_ERR_SOMD_HW_COARSE_DELAY_SET_ERROR\x10\x8a\xd8\xff\xff\xff\xff\xff\xff\xff\x01\x12\x34\n\'SEPIA2_ERR_SOMD_HW_FINE_DELAY_SET_ERROR\x10\x89\xd8\xff\xff\xff\xff\xff\xff\xff\x01\x12.\n!SEPIA2_ERR_SOMD_HW_FW_EPROM_ERROR\x10\x88\xd8\xff\xff\xff\xff\xff\xff\xff\x01\x12=\n0SEPIA2_ERR_SOMD_HW_CRC_ERROR_ON_WRITING_FIRMWARE\x10\x87\xd8\xff\xff\xff\xff\xff\xff\xff\x01\x12:\n-SEPIA2_ERR_SOMD_HW_CALIBRATION_DATA_NOT_FOUND\x10\x86\xd8\xff\xff\xff\xff\xff\xff\xff\x01\x12\x38\n+SEPIA2_ERR_SOMD_HW_WRONG_EXTERNAL_FREQUENCY\x10\x85\xd8\xff\xff\xff\xff\xff\xff\xff\x01\x12=\n0SEPIA2_ERR_SOMD_HW_EXTERNAL_FREQUENCY_NOT_STABLE\x10\x84\xd8\xff\xff\xff\xff\xff\xff\xff\x01\x12\x39\n,SEPIA2_ERR_SLM_ILLEGAL_FREQUENCY_TRIGGERMODE\x10\x8f\xd1\xff\xff\xff\xff\xff\xff\xff\x01\x12-\n SEPIA2_ERR_SLM_ILLEGAL_INTENSITY\x10\x8e\xd1\xff\xff\xff\xff\xff\xff\xff\x01\x12-\n SEPIA2_ERR_SLM_ILLEGAL_HEAD_TYPE\x10\x8d\xd1\xff\xff\xff\xff\xff\xff\xff\x01\x12-\n SEPIA2_ERR_SML_ILLEGAL_INTENSITY\x10\x9b\xcd\xff\xff\xff\xff\xff\xff\xff\x01\x12\x38\n+SEPIA2_ERR_SML_POWER_SCALE_TABLES_NOT_FOUND\x10\x9a\xcd\xff\xff\xff\xff\xff\xff\xff\x01\x12-\n SEPIA2_ERR_SML_ILLEGAL_HEAD_TYPE\x10\x99\xcd\xff\xff\xff\xff\xff\xff\xff\x01\x12\x38\n+SEPIA2_ERR_VUV_VIR_SCALING_TABLES_NOT_FOUND\x10\x91\xcd\xff\xff\xff\xff\xff\xff\xff\x01\x12\x35\n(SEPIA2_ERR_VUV_VIR_DEVICE_TYPE_NOT_FOUND\x10\x90\xcd\xff\xff\xff\xff\xff\xff\xff\x01\x12<\n/SEPIA2_ERR_VUV_VIR_ILLEGAL_TRIGGER_SOURCE_INDEX\x10\x8f\xcd\xff\xff\xff\xff\xff\xff\xff\x01\x12?\n2SEPIA2_ERR_VUV_VIR_ILLEGAL_FREQUENCY_DIVIDER_INDEX\x10\x8e\xcd\xff\xff\xff\xff\xff\xff\xff\x01\x12;\n.SEPIA2_ERR_VUV_VIR_ILLEGAL_TRIGGER_LEVEL_VALUE\x10\x8d\xcd\xff\xff\xff\xff\xff\xff\xff\x01\x12\x36\n)SEPIA2_ERR_VUV_VIR_TRIGGER_DATA_NOT_FOUND\x10\x8c\xcd\xff\xff\xff\xff\xff\xff\xff\x01\x12@\n3SEPIA2_ERR_VUV_VIR_ILLEGAL_PUMP_REGISTER_READ_INDEX\x10\x8b\xcd\xff\xff\xff\xff\xff\xff\xff\x01\x12\x41\n4SEPIA2_ERR_VUV_VIR_ILLEGAL_PUMP_REGISTER_WRITE_INDEX\x10\x8a\xcd\xff\xff\xff\xff\xff\xff\xff\x01\x12\x38\n+SEPIA2_ERR_VUV_VIR_INTENSITY_DATA_NOT_FOUND\x10\x89\xcd\xff\xff\xff\xff\xff\xff\xff\x01\x12\x36\n)SEPIA2_ERR_VUV_VIR_ILLEGAL_INTENSITY_DATA\x10\x88\xcd\xff\xff\xff\xff\xff\xff\xff\x01\x12\x32\n%SEPIA2_ERR_VUV_VIR_UNSUPPORTED_OPTION\x10\x87\xcd\xff\xff\xff\xff\xff\xff\xff\x01\x12\x39\n,SEPIA2_ERR_PRI_UI_CONSTANTS_TABLES_NOT_FOUND\x10\xfd\xcc\xff\xff\xff\xff\xff\xff\xff\x01\x12\x37\n*SEPIA2_ERR_PRI_WAVELENGTHS_TABLE_NOT_FOUND\x10\xfc\xcc\xff\xff\xff\xff\xff\xff\xff\x01\x12\x34\n\'SEPIA2_ERR_PRI_ILLEGAL_WAVELENGTH_INDEX\x10\xfb\xcc\xff\xff\xff\xff\xff\xff\xff\x01\x12=\n0SEPIA2_ERR_PRI_ERROR_ON_WRITING_WAVELENGTH_INDEX\x10\xfa\xcc\xff\xff\xff\xff\xff\xff\xff\x01\x12:\n-SEPIA2_ERR_PRI_OPERATION_MODE_TEXTS_NOT_FOUND\x10\xf9\xcc\xff\xff\xff\xff\xff\xff\xff\x01\x12=\n0SEPIA2_ERR_PRI_OPERATION_MODE_COMMANDS_NOT_FOUND\x10\xf8\xcc\xff\xff\xff\xff\xff\xff\xff\x01\x12\x38\n+SEPIA2_ERR_PRI_ILLEGAL_OPERATION_MODE_INDEX\x10\xf7\xcc\xff\xff\xff\xff\xff\xff\xff\x01\x12\x41\n4SEPIA2_ERR_PRI_ERROR_ON_WRITING_OPERATION_MODE_INDEX\x10\xf6\xcc\xff\xff\xff\xff\xff\xff\xff\x01\x12:\n-SEPIA2_ERR_PRI_TRIGGER_SOURCE_TEXTS_NOT_FOUND\x10\xf5\xcc\xff\xff\xff\xff\xff\xff\xff\x01\x12=\n0SEPIA2_ERR_PRI_TRIGGER_SOURCE_COMMANDS_NOT_FOUND\x10\xf4\xcc\xff\xff\xff\xff\xff\xff\xff\x01\x12\x38\n+SEPIA2_ERR_PRI_ILLEGAL_TRIGGER_SOURCE_INDEX\x10\xf3\xcc\xff\xff\xff\xff\xff\xff\xff\x01\x12\x41\n4SEPIA2_ERR_PRI_ERROR_ON_WRITING_TRIGGER_SOURCE_INDEX\x10\xf2\xcc\xff\xff\xff\xff\xff\xff\xff\x01\x12\x31\n$SEPIA2_ERR_PRI_ILLEGAL_TRIGGER_LEVEL\x10\xf1\xcc\xff\xff\xff\xff\xff\xff\xff\x01\x12:\n-SEPIA2_ERR_PRI_ERROR_ON_WRITING_TRIGGER_LEVEL\x10\xf0\xcc\xff\xff\xff\xff\xff\xff\xff\x01\x12\x32\n%SEPIA2_ERR_PRI_ILLEGAL_INTENSITY_DATA\x10\xef\xcc\xff\xff\xff\xff\xff\xff\xff\x01\x12;\n.SEPIA2_ERR_PRI_ERROR_ON_WRITING_INTENSITY_DATA\x10\xee\xcc\xff\xff\xff\xff\xff\xff\xff\x01\x12\x32\n%SEPIA2_ERR_PRI_ILLEGAL_FREQUENCY_DATA\x10\xed\xcc\xff\xff\xff\xff\xff\xff\xff\x01\x12;\n.SEPIA2_ERR_PRI_ERROR_ON_WRITING_FREQUENCY_DATA\x10\xec\xcc\xff\xff\xff\xff\xff\xff\xff\x01\x12/\n\"SEPIA2_ERR_PRI_ILLEGAL_GATING_DATA\x10\xeb\xcc\xff\xff\xff\xff\xff\xff\xff\x01\x12\x38\n+SEPIA2_ERR_PRI_ERROR_ON_WRITING_GATING_DATA\x10\xea\xcc\xff\xff\xff\xff\xff\xff\xff\x01\x12/\n\"SEPIA2_ERR_SWM_CALTABLES_NOT_FOUND\x10\xd3\xcb\xff\xff\xff\xff\xff\xff\xff\x01\x12/\n\"SEPIA2_ERR_SWM_ILLEGAL_CURVE_INDEX\x10\xd2\xcb\xff\xff\xff\xff\xff\xff\xff\x01\x12\x38\n+SEPIA2_ERR_SWM_ILLEGAL_TIMEBASE_RANGE_INDEX\x10\xd1\xcb\xff\xff\xff\xff\xff\xff\xff\x01\x12\x33\n&SEPIA2_ERR_SWM_ILLEGAL_PULSE_AMPLITUDE\x10\xd0\xcb\xff\xff\xff\xff\xff\xff\xff\x01\x12\x32\n%SEPIA2_ERR_SWM_ILLEGAL_RAMP_SLEW_RATE\x10\xcf\xcb\xff\xff\xff\xff\xff\xff\xff\x01\x12\x35\n(SEPIA2_ERR_SWM_ILLEGAL_PULSE_START_DELAY\x10\xce\xcb\xff\xff\xff\xff\xff\xff\xff\x01\x12\x34\n\'SEPIA2_ERR_SWM_ILLEGAL_RAMP_START_DELAY\x10\xcd\xcb\xff\xff\xff\xff\xff\xff\xff\x01\x12\x33\n&SEPIA2_ERR_SWM_ILLEGAL_WAVE_STOP_DELAY\x10\xcc\xcb\xff\xff\xff\xff\xff\xff\xff\x01\x12-\n SEPIA2_ERR_SWM_ILLEGAL_TABLENAME\x10\xcb\xcb\xff\xff\xff\xff\xff\xff\xff\x01\x12/\n\"SEPIA2_ERR_SWM_ILLEGAL_TABLE_INDEX\x10\xca\xcb\xff\xff\xff\xff\xff\xff\xff\x01\x12/\n\"SEPIA2_ERR_SWM_ILLEGAL_TABLE_FIELD\x10\xc9\xcb\xff\xff\xff\xff\xff\xff\xff\x01\x12\x35\n(SEPIA2_ERR_SWM_EXT_ATTENUATION_NOT_FOUND\x10\xc8\xcb\xff\xff\xff\xff\xff\xff\xff\x01\x12\x35\n(SEPIA2_ERR_SWM_ILLEGAL_ATTENUATION_VALUE\x10\xc7\xcb\xff\xff\xff\xff\xff\xff\xff\x01\x12\x32\n%SEPIA2_ERR_VCL_UI_CONSTANTS_NOT_FOUND\x10\xa1\xcb\xff\xff\xff\xff\xff\xff\xff\x01\x12:\n-SEPIA2_ERR_VCL_TEMPERATURE_CALTABLE_NOT_FOUND\x10\xa0\xcb\xff\xff\xff\xff\xff\xff\xff\x01\x12;\n.SEPIA2_ERR_VCL_BIAS_VOLTAGE_CALTABLE_NOT_FOUND\x10\x9f\xcb\xff\xff\xff\xff\xff\xff\xff\x01\x12/\n\"SEPIA2_ERR_VCL_ILLEGAL_TEMPERATURE\x10\x9e\xcb\xff\xff\xff\xff\xff\xff\xff\x01\x12\x30\n#SEPIA2_ERR_VCL_ILLEGAL_BIAS_VOLTAGE\x10\x9d\xcb\xff\xff\xff\xff\xff\xff\xff\x01\x12/\n\"SEPIA2_ERR_SPM_ILLEGAL_INPUT_VALUE\x10\xa7\xc9\xff\xff\xff\xff\xff\xff\xff\x01\x12/\n\"SEPIA2_ERR_SPM_VALUE_OUT_OF_BOUNDS\x10\xa2\xc9\xff\xff\xff\xff\xff\xff\xff\x01\x12,\n\x1fSEPIA2_ERR_SPM_FW_OUT_OF_MEMORY\x10\x9d\xc9\xff\xff\xff\xff\xff\xff\xff\x01\x12,\n\x1fSEPIA2_ERR_SPM_FW_UPDATE_FAILED\x10\x9b\xc9\xff\xff\xff\xff\xff\xff\xff\x01\x12/\n\"SEPIA2_ERR_SPM_FW_CRC_CHECK_FAILED\x10\x9a\xc9\xff\xff\xff\xff\xff\xff\xff\x01\x12\x34\n\'SEPIA2_ERR_SPM_FW_FLASH_DELETION_FAILED\x10\x99\xc9\xff\xff\xff\xff\xff\xff\xff\x01\x12\x37\n*SEPIA2_ERR_SPM_FW_FUNCTION_NOT_IMPLEMENTED\x10\x97\xc9\xff\xff\xff\xff\xff\xff\xff\x01\x12.\n!SEPIA2_ERR_SPM_FW_FILE_OPEN_ERROR\x10\x93\xc9\xff\xff\xff\xff\xff\xff\xff\x01\x12.\n!SEPIA2_ERR_SPM_FW_FILE_READ_ERROR\x10\x92\xc9\xff\xff\xff\xff\xff\xff\xff\x01\x12\x34\n\'SEPIA2_ERR_SSM_SCALING_TABLES_NOT_FOUND\x10\xf5\xc8\xff\xff\xff\xff\xff\xff\xff\x01\x12\x30\n#SEPIA2_ERR_SSM_ILLEGAL_TRIGGER_MODE\x10\xf4\xc8\xff\xff\xff\xff\xff\xff\xff\x01\x12\x37\n*SEPIA2_ERR_SSM_ILLEGAL_TRIGGER_LEVEL_VALUE\x10\xf3\xc8\xff\xff\xff\xff\xff\xff\xff\x01\x12\x34\n\'SEPIA2_ERR_SSM_ILLEGAL_CORRECTION_VALUE\x10\xf2\xc8\xff\xff\xff\xff\xff\xff\xff\x01\x12\x32\n%SEPIA2_ERR_SSM_TRIGGER_DATA_NOT_FOUND\x10\xf1\xc8\xff\xff\xff\xff\xff\xff\xff\x01\x12=\n0SEPIA2_ERR_SSM_CORRECTION_DATA_COMMAND_NOT_FOUND\x10\xf0\xc8\xff\xff\xff\xff\xff\xff\xff\x01\x12\x34\n\'SEPIA2_ERR_SWS_SCALING_TABLES_NOT_FOUND\x10\xc3\xc8\xff\xff\xff\xff\xff\xff\xff\x01\x12\x31\n$SEPIA2_ERR_SWS_ILLEGAL_HW_MODULETYPE\x10\xc2\xc8\xff\xff\xff\xff\xff\xff\xff\x01\x12\x31\n$SEPIA2_ERR_SWS_MODULE_NOT_FUNCTIONAL\x10\xc1\xc8\xff\xff\xff\xff\xff\xff\xff\x01\x12\x35\n(SEPIA2_ERR_SWS_ILLEGAL_CENTER_WAVELENGTH\x10\xc0\xc8\xff\xff\xff\xff\xff\xff\xff\x01\x12-\n SEPIA2_ERR_SWS_ILLEGAL_BANDWIDTH\x10\xbf\xc8\xff\xff\xff\xff\xff\xff\xff\x01\x12/\n\"SEPIA2_ERR_SWS_VALUE_OUT_OF_BOUNDS\x10\xbe\xc8\xff\xff\xff\xff\xff\xff\xff\x01\x12\'\n\x1aSEPIA2_ERR_SWS_MODULE_BUSY\x10\xbd\xc8\xff\xff\xff\xff\xff\xff\xff\x01\x12\x38\n+SEPIA2_ERR_SWS_FW_WRONG_COMPONENT_ANSWERING\x10\xbb\xc8\xff\xff\xff\xff\xff\xff\xff\x01\x12\x34\n\'SEPIA2_ERR_SWS_FW_UNKNOWN_HW_MODULETYPE\x10\xba\xc8\xff\xff\xff\xff\xff\xff\xff\x01\x12,\n\x1fSEPIA2_ERR_SWS_FW_OUT_OF_MEMORY\x10\xb9\xc8\xff\xff\xff\xff\xff\xff\xff\x01\x12/\n\"SEPIA2_ERR_SWS_FW_VERSION_CONFLICT\x10\xb8\xc8\xff\xff\xff\xff\xff\xff\xff\x01\x12,\n\x1fSEPIA2_ERR_SWS_FW_UPDATE_FAILED\x10\xb7\xc8\xff\xff\xff\xff\xff\xff\xff\x01\x12/\n\"SEPIA2_ERR_SWS_FW_CRC_CHECK_FAILED\x10\xb6\xc8\xff\xff\xff\xff\xff\xff\xff\x01\x12\x36\n)SEPIA2_ERR_SWS_FW_ERROR_ON_FLASH_DELETION\x10\xb5\xc8\xff\xff\xff\xff\xff\xff\xff\x01\x12\x35\n(SEPIA2_ERR_SWS_FW_CALIBRATION_MODE_ERROR\x10\xb4\xc8\xff\xff\xff\xff\xff\xff\xff\x01\x12\x37\n*SEPIA2_ERR_SWS_FW_FUNCTION_NOT_IMPLEMENTED\x10\xb3\xc8\xff\xff\xff\xff\xff\xff\xff\x01\x12\x33\n&SEPIA2_ERR_SWS_FW_WRONG_CALTABLE_ENTRY\x10\xb2\xc8\xff\xff\xff\xff\xff\xff\xff\x01\x12\x39\n,SEPIA2_ERR_SWS_FW_INSUFFICIENT_CALTABLE_SIZE\x10\xb1\xc8\xff\xff\xff\xff\xff\xff\xff\x01\x12.\n!SEPIA2_ERR_SWS_FW_FILE_OPEN_ERROR\x10\x91\xc8\xff\xff\xff\xff\xff\xff\xff\x01\x12.\n!SEPIA2_ERR_SWS_FW_FILE_READ_ERROR\x10\x90\xc8\xff\xff\xff\xff\xff\xff\xff\x01\x12?\n2SEPIA2_ERR_SWS_HW_MODULE_0_ALL_MOTORS_INIT_TIMEOUT\x10\xdf\xc7\xff\xff\xff\xff\xff\xff\xff\x01\x12?\n2SEPIA2_ERR_SWS_HW_MODULE_0_ALL_MOTORS_PLAUSI_CHECK\x10\xde\xc7\xff\xff\xff\xff\xff\xff\xff\x01\x12\x42\n5SEPIA2_ERR_SWS_HW_MODULE_0_ALL_MOTORS_DAC_SET_CURRENT\x10\xdd\xc7\xff\xff\xff\xff\xff\xff\xff\x01\x12:\n-SEPIA2_ERR_SWS_HW_MODULE_0_ALL_MOTORS_TIMEOUT\x10\xdc\xc7\xff\xff\xff\xff\xff\xff\xff\x01\x12\x44\n7SEPIA2_ERR_SWS_HW_MODULE_0_ALL_MOTORS_FLASH_WRITE_ERROR\x10\xdb\xc7\xff\xff\xff\xff\xff\xff\xff\x01\x12@\n3SEPIA2_ERR_SWS_HW_MODULE_0_ALL_MOTORS_OUT_OF_BOUNDS\x10\xda\xc7\xff\xff\xff\xff\xff\xff\xff\x01\x12\x33\n&SEPIA2_ERR_SWS_HW_MODULE_0_I2C_FAILURE\x10\xd9\xc7\xff\xff\xff\xff\xff\xff\xff\x01\x12\x34\n\'SEPIA2_ERR_SWS_HW_MODULE_0_INIT_FAILURE\x10\xd8\xc7\xff\xff\xff\xff\xff\xff\xff\x01\x12>\n1SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_1_DATA_NOT_FOUND\x10\xd6\xc7\xff\xff\xff\xff\xff\xff\xff\x01\x12<\n/SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_1_INIT_TIMEOUT\x10\xd5\xc7\xff\xff\xff\xff\xff\xff\xff\x01\x12<\n/SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_1_PLAUSI_CHECK\x10\xd4\xc7\xff\xff\xff\xff\xff\xff\xff\x01\x12?\n2SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_1_DAC_SET_CURRENT\x10\xd3\xc7\xff\xff\xff\xff\xff\xff\xff\x01\x12\x37\n*SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_1_TIMEOUT\x10\xd2\xc7\xff\xff\xff\xff\xff\xff\xff\x01\x12\x41\n4SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_1_FLASH_WRITE_ERROR\x10\xd1\xc7\xff\xff\xff\xff\xff\xff\xff\x01\x12=\n0SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_1_OUT_OF_BOUNDS\x10\xd0\xc7\xff\xff\xff\xff\xff\xff\xff\x01\x12>\n1SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_2_DATA_NOT_FOUND\x10\xcc\xc7\xff\xff\xff\xff\xff\xff\xff\x01\x12<\n/SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_2_INIT_TIMEOUT\x10\xcb\xc7\xff\xff\xff\xff\xff\xff\xff\x01\x12<\n/SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_2_PLAUSI_CHECK\x10\xca\xc7\xff\xff\xff\xff\xff\xff\xff\x01\x12?\n2SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_2_DAC_SET_CURRENT\x10\xc9\xc7\xff\xff\xff\xff\xff\xff\xff\x01\x12\x37\n*SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_2_TIMEOUT\x10\xc8\xc7\xff\xff\xff\xff\xff\xff\xff\x01\x12\x41\n4SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_2_FLASH_WRITE_ERROR\x10\xc7\xc7\xff\xff\xff\xff\xff\xff\xff\x01\x12=\n0SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_2_OUT_OF_BOUNDS\x10\xc6\xc7\xff\xff\xff\xff\xff\xff\xff\x01\x12>\n1SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_3_DATA_NOT_FOUND\x10\xc2\xc7\xff\xff\xff\xff\xff\xff\xff\x01\x12<\n/SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_3_INIT_TIMEOUT\x10\xc1\xc7\xff\xff\xff\xff\xff\xff\xff\x01\x12<\n/SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_3_PLAUSI_CHECK\x10\xc0\xc7\xff\xff\xff\xff\xff\xff\xff\x01\x12?\n2SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_3_DAC_SET_CURRENT\x10\xbf\xc7\xff\xff\xff\xff\xff\xff\xff\x01\x12\x37\n*SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_3_TIMEOUT\x10\xbe\xc7\xff\xff\xff\xff\xff\xff\xff\x01\x12\x41\n4SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_3_FLASH_WRITE_ERROR\x10\xbd\xc7\xff\xff\xff\xff\xff\xff\xff\x01\x12=\n0SEPIA2_ERR_SWS_HW_MODULE_0_MOTOR_3_OUT_OF_BOUNDS\x10\xbc\xc7\xff\xff\xff\xff\xff\xff\xff\x01\x12?\n2SEPIA2_ERR_SWS_HW_MODULE_1_ALL_MOTORS_INIT_TIMEOUT\x10\xfb\xc6\xff\xff\xff\xff\xff\xff\xff\x01\x12?\n2SEPIA2_ERR_SWS_HW_MODULE_1_ALL_MOTORS_PLAUSI_CHECK\x10\xfa\xc6\xff\xff\xff\xff\xff\xff\xff\x01\x12\x42\n5SEPIA2_ERR_SWS_HW_MODULE_1_ALL_MOTORS_DAC_SET_CURRENT\x10\xf9\xc6\xff\xff\xff\xff\xff\xff\xff\x01\x12:\n-SEPIA2_ERR_SWS_HW_MODULE_1_ALL_MOTORS_TIMEOUT\x10\xf8\xc6\xff\xff\xff\xff\xff\xff\xff\x01\x12\x44\n7SEPIA2_ERR_SWS_HW_MODULE_1_ALL_MOTORS_FLASH_WRITE_ERROR\x10\xf7\xc6\xff\xff\xff\xff\xff\xff\xff\x01\x12@\n3SEPIA2_ERR_SWS_HW_MODULE_1_ALL_MOTORS_OUT_OF_BOUNDS\x10\xf6\xc6\xff\xff\xff\xff\xff\xff\xff\x01\x12\x33\n&SEPIA2_ERR_SWS_HW_MODULE_1_I2C_FAILURE\x10\xf5\xc6\xff\xff\xff\xff\xff\xff\xff\x01\x12\x34\n\'SEPIA2_ERR_SWS_HW_MODULE_1_INIT_FAILURE\x10\xf4\xc6\xff\xff\xff\xff\xff\xff\xff\x01\x12>\n1SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_1_DATA_NOT_FOUND\x10\xf2\xc6\xff\xff\xff\xff\xff\xff\xff\x01\x12<\n/SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_1_INIT_TIMEOUT\x10\xf1\xc6\xff\xff\xff\xff\xff\xff\xff\x01\x12<\n/SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_1_PLAUSI_CHECK\x10\xf0\xc6\xff\xff\xff\xff\xff\xff\xff\x01\x12?\n2SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_1_DAC_SET_CURRENT\x10\xef\xc6\xff\xff\xff\xff\xff\xff\xff\x01\x12\x37\n*SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_1_TIMEOUT\x10\xee\xc6\xff\xff\xff\xff\xff\xff\xff\x01\x12\x41\n4SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_1_FLASH_WRITE_ERROR\x10\xed\xc6\xff\xff\xff\xff\xff\xff\xff\x01\x12=\n0SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_1_OUT_OF_BOUNDS\x10\xec\xc6\xff\xff\xff\xff\xff\xff\xff\x01\x12>\n1SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_2_DATA_NOT_FOUND\x10\xe8\xc6\xff\xff\xff\xff\xff\xff\xff\x01\x12<\n/SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_2_INIT_TIMEOUT\x10\xe7\xc6\xff\xff\xff\xff\xff\xff\xff\x01\x12<\n/SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_2_PLAUSI_CHECK\x10\xe6\xc6\xff\xff\xff\xff\xff\xff\xff\x01\x12?\n2SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_2_DAC_SET_CURRENT\x10\xe5\xc6\xff\xff\xff\xff\xff\xff\xff\x01\x12\x37\n*SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_2_TIMEOUT\x10\xe4\xc6\xff\xff\xff\xff\xff\xff\xff\x01\x12\x41\n4SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_2_FLASH_WRITE_ERROR\x10\xe3\xc6\xff\xff\xff\xff\xff\xff\xff\x01\x12=\n0SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_2_OUT_OF_BOUNDS\x10\xe2\xc6\xff\xff\xff\xff\xff\xff\xff\x01\x12>\n1SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_3_DATA_NOT_FOUND\x10\xde\xc6\xff\xff\xff\xff\xff\xff\xff\x01\x12<\n/SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_3_INIT_TIMEOUT\x10\xdd\xc6\xff\xff\xff\xff\xff\xff\xff\x01\x12<\n/SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_3_PLAUSI_CHECK\x10\xdc\xc6\xff\xff\xff\xff\xff\xff\xff\x01\x12?\n2SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_3_DAC_SET_CURRENT\x10\xdb\xc6\xff\xff\xff\xff\xff\xff\xff\x01\x12\x37\n*SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_3_TIMEOUT\x10\xda\xc6\xff\xff\xff\xff\xff\xff\xff\x01\x12\x41\n4SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_3_FLASH_WRITE_ERROR\x10\xd9\xc6\xff\xff\xff\xff\xff\xff\xff\x01\x12=\n0SEPIA2_ERR_SWS_HW_MODULE_1_MOTOR_3_OUT_OF_BOUNDS\x10\xd8\xc6\xff\xff\xff\xff\xff\xff\xff\x01\x12?\n2SEPIA2_ERR_SWS_HW_MODULE_2_ALL_MOTORS_INIT_TIMEOUT\x10\x97\xc6\xff\xff\xff\xff\xff\xff\xff\x01\x12?\n2SEPIA2_ERR_SWS_HW_MODULE_2_ALL_MOTORS_PLAUSI_CHECK\x10\x96\xc6\xff\xff\xff\xff\xff\xff\xff\x01\x12\x42\n5SEPIA2_ERR_SWS_HW_MODULE_2_ALL_MOTORS_DAC_SET_CURRENT\x10\x95\xc6\xff\xff\xff\xff\xff\xff\xff\x01\x12:\n-SEPIA2_ERR_SWS_HW_MODULE_2_ALL_MOTORS_TIMEOUT\x10\x94\xc6\xff\xff\xff\xff\xff\xff\xff\x01\x12\x44\n7SEPIA2_ERR_SWS_HW_MODULE_2_ALL_MOTORS_FLASH_WRITE_ERROR\x10\x93\xc6\xff\xff\xff\xff\xff\xff\xff\x01\x12@\n3SEPIA2_ERR_SWS_HW_MODULE_2_ALL_MOTORS_OUT_OF_BOUNDS\x10\x92\xc6\xff\xff\xff\xff\xff\xff\xff\x01\x12\x33\n&SEPIA2_ERR_SWS_HW_MODULE_2_I2C_FAILURE\x10\x91\xc6\xff\xff\xff\xff\xff\xff\xff\x01\x12\x34\n\'SEPIA2_ERR_SWS_HW_MODULE_2_INIT_FAILURE\x10\x90\xc6\xff\xff\xff\xff\xff\xff\xff\x01\x12>\n1SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_1_DATA_NOT_FOUND\x10\x8e\xc6\xff\xff\xff\xff\xff\xff\xff\x01\x12<\n/SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_1_INIT_TIMEOUT\x10\x8d\xc6\xff\xff\xff\xff\xff\xff\xff\x01\x12<\n/SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_1_PLAUSI_CHECK\x10\x8c\xc6\xff\xff\xff\xff\xff\xff\xff\x01\x12?\n2SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_1_DAC_SET_CURRENT\x10\x8b\xc6\xff\xff\xff\xff\xff\xff\xff\x01\x12\x37\n*SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_1_TIMEOUT\x10\x8a\xc6\xff\xff\xff\xff\xff\xff\xff\x01\x12\x41\n4SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_1_FLASH_WRITE_ERROR\x10\x89\xc6\xff\xff\xff\xff\xff\xff\xff\x01\x12=\n0SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_1_OUT_OF_BOUNDS\x10\x88\xc6\xff\xff\xff\xff\xff\xff\xff\x01\x12>\n1SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_2_DATA_NOT_FOUND\x10\x84\xc6\xff\xff\xff\xff\xff\xff\xff\x01\x12<\n/SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_2_INIT_TIMEOUT\x10\x83\xc6\xff\xff\xff\xff\xff\xff\xff\x01\x12<\n/SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_2_PLAUSI_CHECK\x10\x82\xc6\xff\xff\xff\xff\xff\xff\xff\x01\x12?\n2SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_2_DAC_SET_CURRENT\x10\x81\xc6\xff\xff\xff\xff\xff\xff\xff\x01\x12\x37\n*SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_2_TIMEOUT\x10\x80\xc6\xff\xff\xff\xff\xff\xff\xff\x01\x12\x41\n4SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_2_FLASH_WRITE_ERROR\x10\xff\xc5\xff\xff\xff\xff\xff\xff\xff\x01\x12=\n0SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_2_OUT_OF_BOUNDS\x10\xfe\xc5\xff\xff\xff\xff\xff\xff\xff\x01\x12>\n1SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_3_DATA_NOT_FOUND\x10\xfa\xc5\xff\xff\xff\xff\xff\xff\xff\x01\x12<\n/SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_3_INIT_TIMEOUT\x10\xf9\xc5\xff\xff\xff\xff\xff\xff\xff\x01\x12<\n/SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_3_PLAUSI_CHECK\x10\xf8\xc5\xff\xff\xff\xff\xff\xff\xff\x01\x12?\n2SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_3_DAC_SET_CURRENT\x10\xf7\xc5\xff\xff\xff\xff\xff\xff\xff\x01\x12\x37\n*SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_3_TIMEOUT\x10\xf6\xc5\xff\xff\xff\xff\xff\xff\xff\x01\x12\x41\n4SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_3_FLASH_WRITE_ERROR\x10\xf5\xc5\xff\xff\xff\xff\xff\xff\xff\x01\x12=\n0SEPIA2_ERR_SWS_HW_MODULE_2_MOTOR_3_OUT_OF_BOUNDS\x10\xf4\xc5\xff\xff\xff\xff\xff\xff\xff\x01\x12\x30\n#SEPIA2_ERR_LIB_TOO_MANY_USB_HANDLES\x10\xd7\xb9\xff\xff\xff\xff\xff\xff\xff\x01\x12\x30\n#SEPIA2_ERR_LIB_ILLEGAL_DEVICE_INDEX\x10\xd6\xb9\xff\xff\xff\xff\xff\xff\xff\x01\x12\x31\n$SEPIA2_ERR_LIB_USB_DEVICE_OPEN_ERROR\x10\xd5\xb9\xff\xff\xff\xff\xff\xff\xff\x01\x12\x36\n)SEPIA2_ERR_LIB_USB_DEVICE_BUSY_OR_BLOCKED\x10\xd4\xb9\xff\xff\xff\xff\xff\xff\xff\x01\x12\x35\n(SEPIA2_ERR_LIB_USB_DEVICE_ALREADY_OPENED\x10\xd3\xb9\xff\xff\xff\xff\xff\xff\xff\x01\x12.\n!SEPIA2_ERR_LIB_UNKNOWN_USB_HANDLE\x10\xd2\xb9\xff\xff\xff\xff\xff\xff\xff\x01\x12\x34\n\'SEPIA2_ERR_LIB_SCM_828_MODULE_NOT_FOUND\x10\xd1\xb9\xff\xff\xff\xff\xff\xff\xff\x01\x12/\n\"SEPIA2_ERR_LIB_ILLEGAL_SLOT_NUMBER\x10\xd0\xb9\xff\xff\xff\xff\xff\xff\xff\x01\x12\x39\n,SEPIA2_ERR_LIB_REFERENCED_SLOT_IS_NOT_IN_USE\x10\xcf\xb9\xff\xff\xff\xff\xff\xff\xff\x01\x12\x35\n(SEPIA2_ERR_LIB_THIS_IS_NO_SCM_828_MODULE\x10\xce\xb9\xff\xff\xff\xff\xff\xff\xff\x01\x12\x35\n(SEPIA2_ERR_LIB_THIS_IS_NO_SOM_828_MODULE\x10\xcd\xb9\xff\xff\xff\xff\xff\xff\xff\x01\x12\x35\n(SEPIA2_ERR_LIB_THIS_IS_NO_SLM_828_MODULE\x10\xcc\xb9\xff\xff\xff\xff\xff\xff\xff\x01\x12\x35\n(SEPIA2_ERR_LIB_THIS_IS_NO_SML_828_MODULE\x10\xcb\xb9\xff\xff\xff\xff\xff\xff\xff\x01\x12\x35\n(SEPIA2_ERR_LIB_THIS_IS_NO_SWM_828_MODULE\x10\xca\xb9\xff\xff\xff\xff\xff\xff\xff\x01\x12\x31\n$SEPIA2_ERR_LIB_THIS_IS_NO_SSM_MODULE\x10\xc9\xb9\xff\xff\xff\xff\xff\xff\xff\x01\x12\x31\n$SEPIA2_ERR_LIB_THIS_IS_NO_SWS_MODULE\x10\xc8\xb9\xff\xff\xff\xff\xff\xff\xff\x01\x12\x31\n$SEPIA2_ERR_LIB_THIS_IS_NO_SPM_MODULE\x10\xc7\xb9\xff\xff\xff\xff\xff\xff\xff\x01\x12+\n\x1eSEPIA2_ERR_LIB_THIS_IS_NO_LMP1\x10\xc6\xb9\xff\xff\xff\xff\xff\xff\xff\x01\x12\x37\n*SEPIA2_ERR_LIB_THIS_IS_NO_SOM_828_D_MODULE\x10\xc5\xb9\xff\xff\xff\xff\xff\xff\xff\x01\x12(\n\x1bSEPIA2_ERR_LIB_NO_MAP_FOUND\x10\xc4\xb9\xff\xff\xff\xff\xff\xff\xff\x01\x12+\n\x1eSEPIA2_ERR_LIB_THIS_IS_NO_LMP8\x10\xc3\xb9\xff\xff\xff\xff\xff\xff\xff\x01\x12\x35\n(SEPIA2_ERR_LIB_THIS_IS_NO_VCL_828_MODULE\x10\xc2\xb9\xff\xff\xff\xff\xff\xff\xff\x01\x12\x39\n,SEPIA2_ERR_LIB_THIS_IS_NO_VUV_NOR_VIR_MODULE\x10\xc1\xb9\xff\xff\xff\xff\xff\xff\xff\x01\x12\x31\n$SEPIA2_ERR_LIB_THIS_IS_NO_PRI_MODULE\x10\xc0\xb9\xff\xff\xff\xff\xff\xff\xff\x01\x12H\n;SEPIA2_ERR_LIB_DEVICE_CHANGED_RE_INITIALISE_USB_DEVICE_LIST\x10\xbf\xb9\xff\xff\xff\xff\xff\xff\xff\x01\x12\x34\n\'SEPIA2_ERR_LIB_INAPPROPRIATE_USB_DEVICE\x10\xbe\xb9\xff\xff\xff\xff\xff\xff\xff\x01\x12\x34\n\'SEPIA2_ERR_LIB_WRONG_USB_DRIVER_VERSION\x10\xfe\xb8\xff\xff\xff\xff\xff\xff\xff\x01\x12,\n\x1fSEPIA2_ERR_LIB_UNKNOWN_FUNCTION\x10\xd4\xb2\xff\xff\xff\xff\xff\xff\xff\x01\x12>\n1SEPIA2_ERR_LIB_ILLEGAL_PARAMETER_ON_FUNCTION_CALL\x10\xca\xb2\xff\xff\xff\xff\xff\xff\xff\x01\x12.\n!SEPIA2_ERR_LIB_UNKNOWN_ERROR_CODE\x10\xf1\xb1\xff\xff\xff\xff\xff\xff\xff\x01\x42\x08\n\x06_error*A\n\rOperationMode\x12\x07\n\x03Off\x10\x00\x12\x0f\n\x0bNarrowPulse\x10\x01\x12\x0e\n\nBroadPulse\x10\x02\x12\x06\n\x02\x43W\x10\x03\x32\xa9\x1b\n\x06Sepia2\x12H\n\x0fLIB_DecodeError\x12\x11.sepia2.rpc.Error\x1a\".sepia2.rpc.LibDecodeErrorResponse\x12=\n\x0eLIB_GetVersion\x12\x16.google.protobuf.Empty\x1a\x13.sepia2.rpc.Version\x12\x43\n\x14LIB_GetLibUSBVersion\x12\x16.google.protobuf.Empty\x1a\x13.sepia2.rpc.Version\x12?\n\x13LIB_IsRunningOnWine\x12\x16.google.protobuf.Empty\x1a\x10.sepia2.rpc.Bool\x12>\n\x0eUSB_OpenDevice\x12\x15.sepia2.rpc.DeviceIdx\x1a\x15.sepia2.rpc.UsbDevice\x12I\n\x19USB_OpenGetSerNumAndClose\x12\x15.sepia2.rpc.DeviceIdx\x1a\x15.sepia2.rpc.UsbDevice\x12\x41\n\x14USB_GetStrDescriptor\x12\x15.sepia2.rpc.DeviceIdx\x1a\x12.sepia2.rpc.String\x12O\n\x14USB_GetStrDescrByIdx\x12#.sepia2.rpc.GetStrDescrByIdxRequest\x1a\x12.sepia2.rpc.String\x12;\n\x10USB_IsOpenDevice\x12\x15.sepia2.rpc.DeviceIdx\x1a\x10.sepia2.rpc.Bool\x12@\n\x0fUSB_CloseDevice\x12\x15.sepia2.rpc.DeviceIdx\x1a\x16.google.protobuf.Empty\x12I\n\x16\x46WR_DecodeErrPhaseName\x12\x1b.sepia2.rpc.ErrPhaseRequest\x1a\x12.sepia2.rpc.String\x12;\n\x0e\x46WR_GetVersion\x12\x15.sepia2.rpc.DeviceIdx\x1a\x12.sepia2.rpc.String\x12?\n\x10\x46WR_GetLastError\x12\x15.sepia2.rpc.DeviceIdx\x1a\x14.sepia2.rpc.FwrError\x12>\n\x12\x46WR_GetWorkingMode\x12\x15.sepia2.rpc.DeviceIdx\x1a\x11.sepia2.rpc.Int32\x12R\n\x12\x46WR_SetWorkingMode\x12$.sepia2.rpc.FwrSetWorkingModeRequest\x1a\x16.google.protobuf.Empty\x12N\n\x1d\x46WR_RollBackToPermanentValues\x12\x15.sepia2.rpc.DeviceIdx\x1a\x16.google.protobuf.Empty\x12K\n\x1a\x46WR_StoreAsPermanentValues\x12\x15.sepia2.rpc.DeviceIdx\x1a\x16.google.protobuf.Empty\x12\x46\n\x10\x46WR_GetModuleMap\x12\x1f.sepia2.rpc.GetModuleMapRequest\x1a\x11.sepia2.rpc.Int32\x12N\n\x19\x46WR_GetModuleInfoByMapIdx\x12\x19.sepia2.rpc.MapIdxRequest\x1a\x16.sepia2.rpc.ModuleInfo\x12N\n\x19\x46WR_GetUptimeInfoByMapIdx\x12\x19.sepia2.rpc.MapIdxRequest\x1a\x16.sepia2.rpc.UptimeInfo\x12X\n\x1c\x46WR_CreateSupportRequestText\x12$.sepia2.rpc.FwrRequestSupportRequest\x1a\x12.sepia2.rpc.String\x12\x42\n\x11\x46WR_FreeModuleMap\x12\x15.sepia2.rpc.DeviceIdx\x1a\x16.google.protobuf.Empty\x12\x45\n\x11PRI_GetDeviceInfo\x12\x16.sepia2.rpc.PriRequest\x1a\x18.sepia2.rpc.PrimaDevInfo\x12V\n\x17PRI_DecodeOperationMode\x12 .sepia2.rpc.OperationModeRequest\x1a\x19.sepia2.rpc.PrimaModeInfo\x12Q\n\x14PRI_GetOperationMode\x12\x16.sepia2.rpc.PriRequest\x1a!.sepia2.rpc.OperationModeResponse\x12P\n\x14PRI_SetOperationMode\x12 .sepia2.rpc.OperationModeRequest\x1a\x16.google.protobuf.Empty\x12T\n\x17PRI_DecodeTriggerSource\x12 .sepia2.rpc.TriggerSourceRequest\x1a\x17.sepia2.rpc.TriggerInfo\x12\x41\n\x14PRI_GetTriggerSource\x12\x16.sepia2.rpc.PriRequest\x1a\x11.sepia2.rpc.Int32\x12P\n\x14PRI_SetTriggerSource\x12 .sepia2.rpc.TriggerSourceRequest\x1a\x16.google.protobuf.Empty\x12Q\n\x19PRI_GetTriggerLevelLimits\x12\x16.sepia2.rpc.PriRequest\x1a\x1c.sepia2.rpc.TriggerLevelInfo\x12@\n\x13PRI_GetTriggerLevel\x12\x16.sepia2.rpc.PriRequest\x1a\x11.sepia2.rpc.Int32\x12N\n\x13PRI_SetTriggerLevel\x12\x1f.sepia2.rpc.TriggerLevelRequest\x1a\x16.google.protobuf.Empty\x12U\n\x16PRI_GetFrequencyLimits\x12\x16.sepia2.rpc.PriRequest\x1a#.sepia2.rpc.FrequencyLimitsResponse\x12=\n\x10PRI_GetFrequency\x12\x16.sepia2.rpc.PriRequest\x1a\x11.sepia2.rpc.Int32\x12K\n\x10PRI_SetFrequency\x12\x1f.sepia2.rpc.SetFrequencyRequest\x1a\x16.google.protobuf.Empty\x12J\n\x13PRI_GetGatingLimits\x12\x16.sepia2.rpc.PriRequest\x1a\x1b.sepia2.rpc.PrimaGatingInfo\x12\x43\n\x11PRI_GetGatingData\x12\x16.sepia2.rpc.PriRequest\x1a\x16.sepia2.rpc.GatingData\x12J\n\x11PRI_SetGatingData\x12\x1d.sepia2.rpc.GatingDataRequest\x1a\x16.google.protobuf.Empty\x12@\n\x14PRI_GetGatingEnabled\x12\x16.sepia2.rpc.PriRequest\x1a\x10.sepia2.rpc.Bool\x12P\n\x14PRI_SetGatingEnabled\x12 .sepia2.rpc.GatingEnabledRequest\x1a\x16.google.protobuf.Empty\x12\x44\n\x18PRI_GetGateHighImpedance\x12\x16.sepia2.rpc.PriRequest\x1a\x10.sepia2.rpc.Bool\x12T\n\x18PRI_SetGateHighImpedance\x12 .sepia2.rpc.HighImpedanceRequest\x1a\x16.google.protobuf.Empty\x12H\n\x14PRI_DecodeWavelength\x12\x1d.sepia2.rpc.WavelengthRequest\x1a\x11.sepia2.rpc.Int32\x12\x41\n\x14PRI_GetWavelengthIdx\x12\x16.sepia2.rpc.PriRequest\x1a\x11.sepia2.rpc.Int32\x12M\n\x14PRI_SetWavelengthIdx\x12\x1d.sepia2.rpc.WavelengthRequest\x1a\x16.google.protobuf.Empty\x12\x45\n\x10PRI_GetIntensity\x12\x1d.sepia2.rpc.WavelengthRequest\x1a\x12.sepia2.rpc.Uint32\x12K\n\x10PRI_SetIntensity\x12\x1f.sepia2.rpc.SetIntensityRequest\x1a\x16.google.protobuf.Emptyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'api_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_OPERATIONMODE']._serialized_start=22752
  _globals['_OPERATIONMODE']._serialized_end=22817
  _globals['_PRIMAGATINGINFO']._serialized_start=54
  _globals['_PRIMAGATINGINFO']._serialized_end=171
  _globals['_TRIGGERLEVELINFO']._serialized_start=173
  _globals['_TRIGGERLEVELINFO']._serialized_end=254
  _globals['_TRIGGERINFO']._serialized_start=256
  _globals['_TRIGGERINFO']._serialized_end=362
  _globals['_PRIMAMODEINFO']._serialized_start=364
  _globals['_PRIMAMODEINFO']._serialized_end=421
  _globals['_PRIMADEVINFO']._serialized_start=423
  _globals['_PRIMADEVINFO']._serialized_end=515
  _globals['_FWRREQUESTSUPPORT']._serialized_start=517
  _globals['_FWRREQUESTSUPPORT']._serialized_end=607
  _globals['_UPTIMEINFO']._serialized_start=609
  _globals['_UPTIMEINFO']._serialized_end=688
  _globals['_MODULEINFO']._serialized_start=690
  _globals['_MODULEINFO']._serialized_end=779
  _globals['_FWRERROR']._serialized_start=781
  _globals['_FWRERROR']._serialized_end=875
  _globals['_USBDEVICE']._serialized_start=877
  _globals['_USBDEVICE']._serialized_end=932
  _globals['_EMPTY']._serialized_start=934
  _globals['_EMPTY']._serialized_end=941
  _globals['_STRING']._serialized_start=943
  _globals['_STRING']._serialized_end=966
  _globals['_BOOL']._serialized_start=968
  _globals['_BOOL']._serialized_end=989
  _globals['_INT32']._serialized_start=991
  _globals['_INT32']._serialized_end=1013
  _globals['_UINT32']._serialized_start=1015
  _globals['_UINT32']._serialized_end=1038
  _globals['_DEVICEIDX']._serialized_start=1040
  _globals['_DEVICEIDX']._serialized_end=1068
  _globals['_LIBDECODEERRORRESPONSE']._serialized_start=1070
  _globals['_LIBDECODEERRORRESPONSE']._serialized_end=1111
  _globals['_VERSION']._serialized_start=1113
  _globals['_VERSION']._serialized_end=1139
  _globals['_GETSTRDESCRBYIDXREQUEST']._serialized_start=1141
  _globals['_GETSTRDESCRBYIDXREQUEST']._serialized_end=1202
  _globals['_ERRPHASEREQUEST']._serialized_start=1204
  _globals['_ERRPHASEREQUEST']._serialized_end=1240
  _globals['_FWRSETWORKINGMODEREQUEST']._serialized_start=1242
  _globals['_FWRSETWORKINGMODEREQUEST']._serialized_end=1299
  _globals['_GETMODULEMAPREQUEST']._serialized_start=1301
  _globals['_GETMODULEMAPREQUEST']._serialized_end=1364
  _globals['_FREQUENCYLIMITSRESPONSE']._serialized_start=1366
  _globals['_FREQUENCYLIMITSRESPONSE']._serialized_end=1427
  _globals['_MAPIDXREQUEST']._serialized_start=1429
  _globals['_MAPIDXREQUEST']._serialized_end=1478
  _globals['_PRIREQUEST']._serialized_start=1480
  _globals['_PRIREQUEST']._serialized_end=1526
  _globals['_SETFREQUENCYREQUEST']._serialized_start=1528
  _globals['_SETFREQUENCYREQUEST']._serialized_end=1609
  _globals['_GATINGENABLEDREQUEST']._serialized_start=1611
  _globals['_GATINGENABLEDREQUEST']._serialized_end=1698
  _globals['_WAVELENGTHREQUEST']._serialized_start=1700
  _globals['_WAVELENGTHREQUEST']._serialized_end=1776
  _globals['_SETINTENSITYREQUEST']._serialized_start=1778
  _globals['_SETINTENSITYREQUEST']._serialized_end=1865
  _globals['_OPERATIONMODEREQUEST']._serialized_start=1867
  _globals['_OPERATIONMODEREQUEST']._serialized_end=1981
  _globals['_OPERATIONMODERESPONSE']._serialized_start=1983
  _globals['_OPERATIONMODERESPONSE']._serialized_end=2048
  _globals['_TRIGGERSOURCEREQUEST']._serialized_start=2050
  _globals['_TRIGGERSOURCEREQUEST']._serialized_end=2134
  _globals['_TRIGGERLEVELREQUEST']._serialized_start=2136
  _globals['_TRIGGERLEVELREQUEST']._serialized_end=2215
  _globals['_GATINGDATA']._serialized_start=2217
  _globals['_GATINGDATA']._serialized_end=2271
  _globals['_GATINGDATAREQUEST']._serialized_start=2273
  _globals['_GATINGDATAREQUEST']._serialized_end=2378
  _globals['_HIGHIMPEDANCEREQUEST']._serialized_start=2380
  _globals['_HIGHIMPEDANCEREQUEST']._serialized_end=2467
  _globals['_FWRREQUESTSUPPORTREQUEST']._serialized_start=2469
  _globals['_FWRREQUESTSUPPORTREQUEST']._serialized_end=2560
  _globals['_ERROR']._serialized_start=2564
  _globals['_ERROR']._serialized_end=22750
  _globals['_ERROR_SEPIA2ERROR']._serialized_start=2626
  _globals['_ERROR_SEPIA2ERROR']._serialized_end=22740
  _globals['_SEPIA2']._serialized_start=22820
  _globals['_SEPIA2']._serialized_end=26317
# @@protoc_insertion_point(module_scope)
